@@ -11,7 +11,7 @@ import os
 import re
 import traceback
 from asyncio import Queue
-from typing import Callable, Any, Awaitable, Set
+from typing import Callable, Any, Awaitable, Set, Optional
 
 import dotenv
 
@@ -138,7 +138,7 @@ def conditionally_add_option(options, query: str, typed_option_no_delimit: str,
     return query.strip()
 
 
-async def query_slapp(query: str):
+async def query_slapp(query: str, limit: Optional[int] = 20):
     """Query Slapp. The response comes back through the callback function that was passed in initialise_slapp."""
     options: Set[str] = set()
 
@@ -163,6 +163,9 @@ async def query_slapp(query: str):
         except Exception as e:
             logging.debug(f"Query started with SW- but was not a friend code: {e} ")
 
+    if limit is not None:
+        options.add(f"--limit {limit}")
+
     logging.debug(f"Posting {query=} to existing Slapp process with options {' '.join(options)} ...")
     await slapp_write_queue.put('--b64 ' + str(base64.b64encode(query.encode("utf-8")), "utf-8") + ' ' +
                                 ' '.join(options))
